"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var debug = require("debug")("connection_helper");
var _ = require("lodash");
var constants_1 = require("./constants");
var http_request_helper_1 = require("./http_request_helper");
var http_request_mock_1 = require("./http_request_mock");
var postgres_request_helper_1 = require("./postgres_request_helper");
var ConnectionHelper = /** @class */ (function () {
    function ConnectionHelper(serviceConfig, servicePaths) {
        if (serviceConfig === void 0) { serviceConfig = {}; }
        if (servicePaths === void 0) { servicePaths = {}; }
        this.serviceConfig = serviceConfig;
        this.servicePaths = servicePaths;
    }
    ConnectionHelper.prototype.forServicePath = function (servicePath) {
        var serviceData = this.getServiceDetailsFromPath(servicePath);
        debug("serviceData");
        debug(serviceData);
        switch (serviceData.type) {
            case constants_1.ServiceType.HTTP:
                return new http_request_helper_1.default(serviceData);
            // case ServiceType.CSV:
            //
            case constants_1.ServiceType.POSTGRES:
                return new postgres_request_helper_1.default(serviceData);
            default:
                return null;
        }
    };
    ConnectionHelper.prototype.mockServicePath = function (servicePath, data) {
        var serviceData = this.getServiceDetailsFromPath(servicePath);
        if (serviceData.type === constants_1.ServiceType.HTTP) {
            return new http_request_mock_1.default().mock(serviceData, data);
        }
        // else if (type === ServiceType.POSTGRES) {
        // }
    };
    ConnectionHelper.prototype.getServiceDetailsFromPath = function (path) {
        var servicePathData = this.servicePaths.paths.find(function (cur) { return cur.id === path; });
        var serviceData = this.serviceConfig.services.find(function (service) { return service.id === servicePathData.service; });
        if (!serviceData) {
            throw new Error("Config not found for " + servicePathData.service);
        }
        var toReturn = {};
        _.merge(toReturn, serviceData);
        _.merge(toReturn, servicePathData);
        return toReturn;
    };
    return ConnectionHelper;
}());
exports.default = ConnectionHelper;
//# sourceMappingURL=connection_helper.js.map