"use strict";
/// <reference path="run_blackbox_tests.d.ts"/>
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var chai_1 = require("chai");
var chaiJestSnapshot = require("chai-jest-snapshot");
var fs = require("fs");
var glob = require("glob");
var nock = require("nock");
var path = require("path");
var sinon = require("sinon");
var connection_helper_1 = require("./connection_helper");
var lodash_1 = require("lodash");
chai.use(chaiJestSnapshot);
var printServiceConfig = function (serviceDetails) {
    var url = serviceDetails.url, port = serviceDetails.port, method = serviceDetails.method, pathRegex = serviceDetails.pathRegex;
    console.log("### Service details");
    console.log(serviceDetails);
};
var generateTestName = function (queryName, variant) {
    return __assign({}, variant, { name: queryName + " (" + variant.name + ")" });
};
var blackboxTestsRunner = function (opts) {
    var graphqlFn = opts.graphqlFn, serviceConfig = opts.serviceConfig, servicePaths = opts.servicePaths, fixturesDir = opts.fixturesDir, cleanupFn = opts.cleanupFn, _a = opts.exclude, exclude = _a === void 0 ? [] : _a, _b = opts.include, include = _b === void 0 ? [] : _b, debug = opts.debug;
    var files = glob.sync(fixturesDir + "/*.graphql");
    var connHelper = new connection_helper_1.default(serviceConfig, servicePaths);
    var setUpMocks = function (mocks) {
        mocks.forEach(function (mock) {
            connHelper.mockServicePath(mock.service_path, mock.data);
        });
    };
    describe("Black box tests", function () {
        var clock = null;
        beforeEach(function () {
            cleanupFn();
            chaiJestSnapshot.configureUsingMochaContext(this);
        });
        afterEach(function () {
            nock.cleanAll();
        });
        files.forEach(function (file) {
            var queryName = path.basename(file, ".graphql");
            if (include.length > 0 && !include.includes(queryName)) {
                return;
            }
            if (exclude.includes(queryName)) {
                console.log("-> Ignored " + queryName);
                return;
            }
            var config = JSON.parse(fs.readFileSync(fixturesDir + "/" + queryName + ".config.json", "utf8"));
            var testsInFile = config.variants
                ? config.variants.map(function (variant) { return generateTestName(queryName, variant); })
                : [{ name: "" + queryName, mocks: config.mocks, other: config.other }];
            testsInFile.map(function (test) {
                it("" + test.name, function () { return __awaiter(_this, void 0, void 0, function () {
                    var query, fakeTimer, result;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                query = fs.readFileSync(file, "utf8");
                                setUpMocks(test.mocks);
                                fakeTimer = lodash_1.get(test, 'other.fakeTimer', 0);
                                if (fakeTimer) {
                                    clock = sinon.useFakeTimers({ now: fakeTimer });
                                }
                                return [4 /*yield*/, graphqlFn(query, test.variables || {})];
                            case 1:
                                result = _a.sent();
                                chaiJestSnapshot.setFilename(fixturesDir + "/" + queryName + ".snap");
                                if (!nock.isDone()) {
                                    console.log("Pending mocks");
                                    console.log(nock.pendingMocks());
                                }
                                if (debug.printResult) {
                                    console.log(JSON.stringify(result, null, 2));
                                }
                                chai_1.expect(nock.isDone()).to.equal(true, "Not all mocked endpoints were hit");
                                chai_1.expect(result).to.matchSnapshot();
                                return [2 /*return*/];
                        }
                    });
                }); });
            });
        });
    });
};
exports.default = blackboxTestsRunner;
//# sourceMappingURL=run_blackbox_tests.js.map