import ConnectionHelper from "../connection_helper";
import HttpRequestHelper from "../http_request_helper";

const serviceConfig = {
  services: [
    {
      id: "SOME_SERVICE",
      description: "Nice service",
      name: "Some service",
      type: "HTTP",
      requestOptions: {
        host: "{{{host}}}",
        port: "{{port}}",
        query: {
          key: "{{key}}"
        }
      },
      fromEnv: {
        host: "SERVICE_BASE_URL",
        port: "SERVICE_PORT",
        key: "SERVICE_API_KEY"
      }
    }
  ]
};

const servicePaths = {
  paths: [
    {
      id: "SOME_SERVICE/someEndpoint",
      service: "SOME_SERVICE",
      requestOptions: {
        path: "/some/endpoint",
        query: {
          param1: "{{param1}}",
          param2: "{{param2}}"
        }
      }
    }
  ]
};

describe("Connection helper", () => {
  describe("#forServicePath", () => {
    it("should return a HTTP request helper for a HTTP service", () => {
      const connHelper = new ConnectionHelper(serviceConfig, servicePaths);
      const conn = connHelper.forServicePath("SOME_SERVICE/someEndpoint");
      expect(conn).toBeInstanceOf(HttpRequestHelper);
    });
  });
  describe("#getServiceDetailsFromPath", () => {
    it("should have the correct service data", () => {
      const connHelper = new ConnectionHelper(serviceConfig, servicePaths);
      const serviceDetails = connHelper.getServiceDetailsFromPath(
        "SOME_SERVICE/someEndpoint"
      );
      const expected = {
        id: "SOME_SERVICE/someEndpoint",
        service: "SOME_SERVICE",
        description: "Nice service",
        name: "Some service",
        type: "HTTP",
        requestOptions: {
          host: "{{{host}}}",
          port: "{{port}}",
          path: "/some/endpoint",
          query: {
            key: "{{key}}",
            param1: "{{param1}}",
            param2: "{{param2}}"
          }
        },
        fromEnv: {
          host: "SERVICE_BASE_URL",
          port: "SERVICE_PORT",
          key: "SERVICE_API_KEY"
        }
      };
      expect(serviceDetails).toEqual(expected);
    });
  });
});
