const debug = require("debug")("connection_helper");
import * as _ from "lodash";
import { ServiceType } from "./constants";
import HttpRequestHelper from "./http_request_helper";
import HttpRequestMock from "./http_request_mock";
import PostgresRequestHelper from "./postgres_request_helper";
import { RequestHelper } from "./request_helper";

class ConnectionHelper {
  private readonly serviceConfig: any;
  private readonly servicePaths: any;

  constructor(serviceConfig = {}, servicePaths = {}) {
    this.serviceConfig = serviceConfig;
    this.servicePaths = servicePaths;
  }

  public forServicePath(servicePath: string): RequestHelper {
    const serviceData = this.getServiceDetailsFromPath(servicePath);

    debug("serviceData");
    debug(serviceData);
    switch (serviceData.type) {
      case ServiceType.HTTP:
        return new HttpRequestHelper(serviceData);
      // case ServiceType.CSV:
      //
      case ServiceType.POSTGRES:
        return new PostgresRequestHelper(serviceData);

      default:
        return null;
    }
  }

  public mockServicePath(servicePath: string, data: string) {
    const serviceData = this.getServiceDetailsFromPath(servicePath);

    if (serviceData.type === ServiceType.HTTP) {
      return new HttpRequestMock().mock(serviceData, data);
    }
    // else if (type === ServiceType.POSTGRES) {
    // }
  }

  public getServiceDetailsFromPath(path): any {
    const servicePathData = this.servicePaths.paths.find(
      cur => cur.id === path
    );
    const serviceData = this.serviceConfig.services.find(
      service => service.id === servicePathData.service
    );
    if (!serviceData) {
      throw new Error(`Config not found for ${servicePathData.service}`);
    }

    const toReturn = {};
    _.merge(toReturn, serviceData);
    _.merge(toReturn, servicePathData);
    return toReturn;
  }
}

export default ConnectionHelper;
