import * as _ from "lodash";
import * as Mustache from "mustache";
import ServiceRenderer from "./service_renderer";

class HttpServiceRenderer extends ServiceRenderer {
  public render() {
    this.mergeArgsAndEnv();
    return {
      json: _.get(this.serviceData, "requestOptions.json", false),
      query: this.renderQuery(),
      baseUrl: this.renderBaseUrl(),
      port: this.renderPort(),
      path: this.renderPath()
    };
  }

  private renderBaseUrl() {
    const rawHost = _.get(this.serviceData, "requestOptions.host", "");
    return Mustache.render(rawHost, this.templateArgs);
  }

  private renderPort() {
    const rawPort = _.get(this.serviceData, "requestOptions.port", "");
    return Mustache.render(rawPort, this.templateArgs);
  }

  private renderPath() {
    const path = _.get(this.serviceData, "requestOptions.path", "");
    return Mustache.render(path, this.templateArgs);
  }

  private renderQuery() {
    const queryWithArgs = _.get(this.serviceData, "requestOptions.query", {});
    Object.keys(queryWithArgs).forEach(query => {
      queryWithArgs[query] = Mustache.render(
        queryWithArgs[query],
        this.templateArgs
      );
    });

    return queryWithArgs;
  }
}

export default HttpServiceRenderer;
