const debug = require("debug")("postgres_request_helper");
import * as _ from "lodash/fp";
import * as Mustache from "mustache";
import { Pool } from "pg";
import dbPools from "./db_pool";
import PostgresServiceRenderer from "./postgres_service_renderer";
import { RequestHelper } from "./request_helper";

export default class PostgresRequestHelper extends RequestHelper {
  private serviceData: any;
  private renderer: PostgresServiceRenderer;

  constructor(serviceData) {
    super();
    this.serviceData = _.cloneDeep(serviceData);
  }

  public run(args) {
    this.renderer = new PostgresServiceRenderer(this.serviceData, args);
    const rendered = this.renderer.render();

    const poolOpts = {
      user: rendered.user,
      password: rendered.pass,
      host: rendered.host,
      port: rendered.port,
      database: rendered.database
    };
    debug(rendered);

    const poolKey: any = JSON.stringify(poolOpts);
    if (!dbPools.hasOwnProperty(poolKey)) {
      debug("Pool does not exist for key");
      const opts = {
        ...poolOpts,
        ssl: true
      };
      dbPools[poolKey] = new Pool(opts);
    }
    const pool = dbPools[poolKey];
    return pool
      .connect()
      .then(client => client.query(rendered.query))
      .then(res => res.rows);
    // .finally((client) => client.release());
  }
}
