import * as _ from "lodash";
import * as Mustache from "mustache";
import ServiceRenderer from "./service_renderer";

export default class PostgresServiceRenderer extends ServiceRenderer {
  public render() {
    this.mergeArgsAndEnv();
    return {
      user: this.renderUser(),
      pass: this.renderPass(),
      host: this.renderHost(),
      port: this.renderPort(),
      database: this.renderDatabase(),
      query: this.renderQuery()
    };
  }

  private renderUser() {
    const rawUser = _.get(this.serviceData, "requestOptions.user", "");
    return Mustache.render(rawUser, this.templateArgs);
  }

  private renderPass() {
    const rawPass = _.get(this.serviceData, "requestOptions.pass", "");
    return Mustache.render(rawPass, this.templateArgs);
  }

  private renderHost() {
    const rawHost = _.get(this.serviceData, "requestOptions.host", "");
    return Mustache.render(rawHost, this.templateArgs);
  }
  private renderPort() {
    const rawPort = _.get(this.serviceData, "requestOptions.port", "");
    return Mustache.render(rawPort, this.templateArgs);
  }

  private renderDatabase() {
    const rawDatabase = _.get(this.serviceData, "requestOptions.database", "");
    return Mustache.render(rawDatabase, this.templateArgs);
  }

  private renderQuery() {
    let queryWithArgs = _.get(
      this.serviceData,
      "requestOptions.query",
      []
    ).join("\n");
    queryWithArgs = Mustache.render(queryWithArgs, this.templateArgs);

    return queryWithArgs;
  }
}
